@@ -114,13 +114,13 @@ static int check_kmods(void)
 
 	/* We only need to do this for PHB/SLOT/PCI operations */
 	if (usr_drc_type != DRC_TYPE_PCI && usr_drc_type != DRC_TYPE_PHB &&
-	    usr_drc_type != DRC_TYPE_SLOT)
+	    usr_drc_type != DRC_TYPE_SLOT && !display_capabilities)
 		return 0;
 
 	/* We don't use rpadlar_io/rpaphp for PCI operations run with the
 	 * -v / virtio flag, which relies on generic PCI rescan instead
 	 */
-	if (usr_drc_type == DRC_TYPE_PCI && pci_virtio)
+	if (usr_drc_type == DRC_TYPE_PCI && pci_virtio && !display_capabilities)
 		return 0;
 
 	/* Before checking for dlpar capability, we need to ensure that
@@ -974,6 +974,8 @@ char *php_slot_type_msg[]={
 	"PCI-E capable, Rev 4, 16x lanes with 1 lane connected",    /* 40 */
 	"PCI-E capable, Rev 4, 16x lanes with 8x lanes connected",
 	"PCI-E capable, Rev 4, 16x lanes with 16x lanes connected",
+	"U.2 PCI-E capable, Rev 3, 4x lanes with 4x lanes connected",
+	"U.2 PCI-E capable, Rev 4, 4x lanes with 4x lanes connected",
 };
 
 char *
@@ -984,7 +986,7 @@ node_type(struct dr_node *node)
 
 	desc_msg_num = atoi(node->drc_type);
 	if ((desc_msg_num >= 1 &&  desc_msg_num <= 8) ||
-	    (desc_msg_num >= 11 && desc_msg_num <= 42))
+	    (desc_msg_num >= 11 && desc_msg_num <= 44))
 		desc = php_slot_type_msg[desc_msg_num];
 	else {
 		switch (node->dev_type) {
